forceRefresh property
If true, forces a fresh fetch from server and updates cache, ignoring existing cached data
Implementation
final bool forceRefresh;
If true, forces a fresh fetch from server and updates cache, ignoring existing cached data
final bool forceRefresh;